@@ -1,12 +1,14 @@
 
 from __future__ import annotations
 
+import deprecated
 import typing as t
 
 from nr.util.generic import T_co
 from ._supplier import Supplier
 
 
+@deprecated.deprecated('use `nr.util.once.Once` instead')
 class Once(Supplier[T_co]):
 
   def __init__(self, supplier: Supplier[T_co]) -> None:
