@@ -1,12 +1,14 @@
 
 from __future__ import annotations
 
+import deprecated
 import typing as t
 import typing_extensions as te
 
 from nr.util.generic import T_co, U
 
 
+@deprecated.deprecated('will be removed in a future version')
 def supplier_get(value: Supplier[T_co] | U) -> T_co | U:
   """ A helper method to invoke a supplier, if *value* is a supplier, or return the value directory. This is
   useful in particular for patterns where a static value as well as a supplier is a valid value for the variable.
@@ -23,11 +25,13 @@ def supplier_get(value: Supplier[T_co] | U) -> T_co | U:
   return value
 
 
+@deprecated.deprecated('use `nr.util.types.Supplier` instead')
 class Supplier(te.Protocol[T_co]):
 
   def __call__(self) -> T_co:
     ...
 
 
+@deprecated.deprecated('will be removed in a future version')
 class ContextSupplier(Supplier[t.ContextManager[T_co]]):
   ...
