@@ -5,7 +5,7 @@ the object contained in a "variable" can be interchanged or different based on t
 """
 
 from ._base import get_name, get, BaseProxy
-from ._proxy import bind, is_bound, proxy, Proxy
+from ._proxy import bind, is_bound, proxy, set_value, Proxy
 from ._stackable import empty, push, pop, StackableProxy
 from ._threadlocal import threadlocal, ThreadLocalProxy
 from ._contextlocal import contextlocal, ContextLocalProxy
@@ -13,7 +13,7 @@ from ._contextlocal import contextlocal, ContextLocalProxy
 
 __all__ = [
   'get_name', 'get', 'BaseProxy',
-  'bind', 'is_bound', 'proxy', 'Proxy',
+  'bind', 'is_bound', 'proxy', 'set_value', 'Proxy',
   'empty', 'push', 'pop', 'StackableProxy',
   'threadlocal', 'ThreadLocalProxy',
   'contextlocal', 'ContextLocalProxy',
